# Rango Python SDK 
Install the SDK using the following command:

`pip install rango-sdk`

### Set up `.env`:

```dotenv
TOKEN='xxxx'  # your bot token here
RANGO_API_KEY='YourRangoApi'
RANGO_BASE_URL='https://api.rango.exchange/'
WEBHOOK_URL='YourServerAddress'
DEVELOPMENT='true' # For testing
```

Then just import `rango_client` and start using it.